from flask import Flask
from flask import request
import pandas as pd
import pickle
from sklearn.linear_model import LinearRegression


# Create app.
app = Flask(__name__)


@app.route('/retrain', methods=['POST'])
def retrain():
    print('retrain STARTED!')
    # Read CSV.
    house_df = pd.read_csv('USA_Housing.csv')

    # Create X for data and y for labels.
    X = house_df[[
        'Avg. Area Income',
        'Avg. Area House Age',
        'Avg. Area Number of Rooms',
        'Avg. Area Number of Bedrooms',
        'Area Population'
    ]]
    y = house_df['Price']

    # Create linear regression model.
    lm = LinearRegression()

    # Fit model with X and y.
    lm.fit(X, y)

    # Save model in pickle.
    pickle.dump(lm, open('lr_model.pkl', 'wb'))

    return 'OK', 200


@app.route('/predict', methods=['POST'])
def predict():
    # Get data from request body.
    data = request.get_json()

    # Create the dataset to predict.
    X = pd.DataFrame({
        'Avg. Area Income': [float(data['income'])],
        'Avg. Area House Age': [float(data['age'])],
        'Avg. Area Number of Rooms': [float(data['n_rooms'])],
        'Avg. Area Number of Bedrooms': [float(data['n_bedrooms'])],
        'Area Population': [float(data['population'])]
    })

    # Load model from pickle.
    lm = pickle.load(open('lr_model.pkl', 'rb'))

    # Get the dataset prediction.
    prediction = lm.predict(X)

    return {'Predicted price': round(prediction[0], 2)}


if __name__ == "__main__":
    app.run(debug=True, host='127.0.0.1', port=5000)
